==> haskell-libyaml-0.1.4-153.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-libyaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   libyaml
version:                0.1.4
visibility:             public
id:                     libyaml-0.1.4-BUBBxYwvUBe2CVGVwDzHtA
key:                    libyaml-0.1.4-BUBBxYwvUBe2CVGVwDzHtA
license:                BSD-3-Clause
maintainer:             Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:              stable
homepage:               https://github.com/snoyberg/yaml#readme
synopsis:               Low-level, streaming YAML interface.
description:
    README and API documentation are available at <https://www.stackage.org/package/libyaml>

category:               Text
abi:                    54d6e6eabcd0b5636180e798ef9f3c8f
exposed:                True
exposed-modules:        Text.Libyaml
hidden-modules:         Paths_libyaml
import-dirs:            /usr/lib/ghc-9.6.6/site-local/libyaml-0.1.4
library-dirs:           /usr/lib/ghc-9.6.6/site-local/libyaml-0.1.4 /usr/lib
library-dirs-static:    /usr/lib/ghc-9.6.6/site-local/libyaml-0.1.4 /usr/lib
dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-libyaml
hs-libraries:           HSlibyaml-0.1.4-BUBBxYwvUBe2CVGVwDzHtA
extra-libraries:        yaml
extra-libraries-static: yaml
include-dirs:           /usr/include
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-252yfbtdylIFaQqQ0JKO9q
    resourcet-1.2.6-BDQ4bs2ZkKrFMSf2ISkWBx

haddock-interfaces:     /usr/share/doc/haskell-libyaml/html/libyaml.haddock
haddock-html:           /usr/share/doc/haskell-libyaml/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libyaml-0.1.4-154-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-libyaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   libyaml
version:                0.1.4
visibility:             public
id:                     libyaml-0.1.4-FqSNdc5sCXQ59Bccr5psT6
key:                    libyaml-0.1.4-FqSNdc5sCXQ59Bccr5psT6
license:                BSD-3-Clause
maintainer:             Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:              stable
homepage:               https://github.com/snoyberg/yaml#readme
synopsis:               Low-level, streaming YAML interface.
description:
    README and API documentation are available at <https://www.stackage.org/package/libyaml>

category:               Text
abi:                    ac9dd0d40e3280e6c58728b695a8e51b
exposed:                True
exposed-modules:        Text.Libyaml
hidden-modules:         Paths_libyaml
import-dirs:            /usr/lib/ghc-9.6.6/site-local/libyaml-0.1.4
library-dirs:           /usr/lib/ghc-9.6.6/site-local/libyaml-0.1.4 /usr/lib
library-dirs-static:    /usr/lib/ghc-9.6.6/site-local/libyaml-0.1.4 /usr/lib
dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-libyaml
hs-libraries:           HSlibyaml-0.1.4-FqSNdc5sCXQ59Bccr5psT6
extra-libraries:        yaml
extra-libraries-static: yaml
include-dirs:           /usr/include
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh
    resourcet-1.2.6-7GW6wEwAkCf499WYv26LMs

haddock-interfaces:     /usr/share/doc/haskell-libyaml/html/libyaml.haddock
haddock-html:           /usr/share/doc/haskell-libyaml/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
